%define anolis_release 1
%global systemd_units tracker-xdg-portal-3

Name:           tracker
Version:        3.5.3
Release:        %{anolis_release}%{?dist}
Summary:        Desktop-neutral metadata database and search tool

License:        GPLv2+
URL:            https://gnome.pages.gitlab.gnome.org/tracker/
Source0:        https://download.gnome.org/sources/tracker/3.5/tracker-%{version}.tar.xz

BuildRequires: asciidoc
BuildRequires: gettext
BuildRequires: libstemmer-devel
BuildRequires: meson >= 0.55
BuildRequires: python3-gobject
BuildRequires: systemd-rpm-macros
BuildRequires: vala
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(gio-2.0) >= 2.52.0
BuildRequires: pkgconfig(gio-unix-2.0) >= 2.52.0
BuildRequires: pkgconfig(glib-2.0) >= 2.52.0
BuildRequires: pkgconfig(gmodule-2.0) >= 2.52.0
BuildRequires: pkgconfig(gobject-2.0) >= 2.52.0
BuildRequires: pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(icu-i18n) > 4.8.1.1
BuildRequires: pkgconfig(icu-uc) > 4.8.1.1
BuildRequires: pkgconfig(json-glib-1.0) >= 1.4
BuildRequires: pkgconfig(libsoup-3.0)
BuildRequires: pkgconfig(libxml-2.0) > 2.6
BuildRequires: pkgconfig(sqlite3) > 3.20.0
BuildRequires: /usr/bin/dbus-run-session

Obsoletes:      tracker3 < 3.1.0~rc-2
Conflicts:      tracker3 < 3.1.0~rc-2
Provides:       tracker3 = %{version}-%{release}

Requires: libtracker-sparql = %{version}-%{release}

Recommends: tracker-miners

%description
Tracker is a powerful desktop-neutral first class object database,
tag/metadata database and search tool.

It consists of a common object database that allows entities to have an
almost infinite number of properties, metadata (both embedded/harvested as
well as user definable), a comprehensive database of keywords/tags and
links to other entities.

It provides additional features for file based objects including context
linking and audit trails for a file object.

Metadata indexers are provided by the tracker-miners package.


%package -n     libtracker-sparql
Summary:        Tracker SPARQL library
License:        LGPLv2+
Recommends:     %{name} = %{version}-%{release}
Obsoletes:      libtracker-sparql3 < 3.1.0~rc
Conflicts:      libtracker-sparql3 < 3.1.0~rc
Provides:       libtracker-sparql3 = %{version}-%{release}
Obsoletes:      libtracker-control < 2.3.6
Obsoletes:      libtracker-miner < 2.3.6

%description -n libtracker-sparql
This package contains the libtracker-sparql library.


%package        devel
Summary:        Development files for %{name}
Requires:       libtracker-sparql = %{version}-%{release}
Obsoletes:      tracker3-devel < 3.1.0~rc
Conflicts:      tracker3-devel < 3.1.0~rc
Provides:       tracker3-devel = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch
Obsoletes:      tracker3-doc < 3.1.0~rc
Conflicts:      tracker3-doc < 3.1.0~rc
Provides:       tracker3-doc = %{version}-%{release}

%description doc
The %{name}-devel package contains the documentation for %{name}.


%prep
%autosetup -p1 -n tracker-%{version}


%build
%meson \
  -Dunicode_support=icu \
  -Dsystemd_user_services_dir=%{_userunitdir} \
  %{nil}

%meson_build


%install
%meson_install

%generate_compatibility_deps

%find_lang tracker3


%post
%systemd_user_post %{systemd_units}

%preun
%systemd_user_preun %{systemd_units}

%postun
%systemd_user_postun_with_restart %{systemd_units}


%files -f tracker3.lang
%license COPYING COPYING.GPL
%{_bindir}/tracker3
%{_libexecdir}/tracker3/
%{_libexecdir}/tracker-xdg-portal-3
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/tracker3
%{_datadir}/dbus-1/services/org.freedesktop.portal.Tracker.service
%{_mandir}/man1/tracker*.1*
%{_userunitdir}/tracker-xdg-portal-3.service

%files -n libtracker-sparql
%dir %{abidir}
%license COPYING COPYING.LGPL
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Tracker-3.0.typelib
%{_libdir}/libtracker-sparql-3.0.so.0*
%{abidir}/libtracker-sparql*.dump
%{_libdir}/tracker-3.0/
%{abidir}/libtracker-parser-libicu.dump
%{_datadir}/tracker3/
%{abidir}/*.dump

%files devel
%{_includedir}/tracker-3.0/
%{_libdir}/libtracker-sparql-3.0.so
%{_libdir}/pkgconfig/*.pc
%dir %{_libdir}/tracker-3.0
%{_libdir}/tracker-3.0/trackertestutils/
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/tracker-sparql-3.0.*
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Tracker-3.0.gir

%files doc
%license docs/reference/COPYING
%{_datadir}/doc/Tracker-3.0
%doc AUTHORS NEWS README.md

%changelog
* Mon Jul 10 2023 Funda Wang <fundawang@yeah.net> - 3.5.3-1
- New version 3.5.3

* Sat May 13 2023 Funda Wang <fundawang@yeah.net> - 3.5.2-1
- New version 3.5.2

* Wed Apr 26 2023 Funda Wang <fundawang@yeah.net> - 3.5.1-1
- New version 3.5.1

* Thu Apr 06 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.5.0-2
- rebuild with libsoup3

* Mon Mar 20 2023 Funda Wang <fundawang@yeah.net> - 3.5.0-1
- New version 3.5.0

* Tue Dec 6 2022 Funda Wang <fundawang@yeah.net> - 3.4.2-1
- New version 3.4.2

* Mon Dec 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.4.1-2
- rebuild with icu update

* Fri Nov 25 2022 Funda Wang <fundawang@yeah.net> - 3.4.1-1
- New version 3.4.1

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.3.0-3
- optimise spec file

- Tue Apr 19 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.3.0-2
- Bump version to rebuild with icu

* Wed Apr 13 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.3.0-1
- init from upstream
